@@ -9,7 +9,7 @@ from ytscraper.helper.echo import echov
 
 @click.group()
 @click.option("--config-path", "-c", type=click.Path(), help="YAML configuration file.")
-@click.option("--verbose", "-v", is_flag=True, help="Show more verbose output.")
+@click.option("--verbose", "-v", is_flag=True, help="Show more output.")
 @click.pass_context
 def run(context, config_path, verbose):
     echov("Reading configuration file.", verbose)
@@ -24,4 +24,3 @@ def run(context, config_path, verbose):
 
 run.add_command(search.search)
 run.add_command(fetch.fetch)
-
